@@ -491,21 +491,18 @@ plot.isofit <- function(x, cex.scale = 0.2, ...) {
   d.stop <- FALSE
   d <- 0
   
+  rho <- ifelse(utils::packageVersion(pkg = "spaMM") < "2.4",  model$corrPars$rho, model$corrPars[[1]]$rho)
+  nu  <- ifelse(utils::packageVersion(pkg = "spaMM") < "2.4",  model$corrPars$nu, model$corrPars[[1]]$nu)
+  
   while ((d < 50000) & !d.stop) {
     d <- d + 10
-    m <- spaMM::MaternCorr(d = d,
-                           rho = model$corrPars$rho,
-                           nu = model$corrPars$nu
-    )
+    m <- spaMM::MaternCorr(d = d, rho = rho, nu = nu)
     if (m < limit) d.stop <- TRUE
   }
   
   distances <- seq(0, d, 1)
   
-  m <- spaMM::MaternCorr(d = distances,
-                         rho = model$corrPars$rho,
-                         nu = model$corrPars$nu
-  )
+  m <- spaMM::MaternCorr(d = distances, rho = rho, nu = nu)
   
   graphics::plot(m ~ distances,
                  type = "l",
